==> cpm-1.1.0.tar.gz: cpm-1.1.0/collectives/loggp_collectives.h <==
#ifndef LogGP_COLLECTIVES_H_
#define LogGP_COLLECTIVES_H_

#include "plogp.h"
#include "cpm_collectives.h"

/*!
 * \defgroup LogGP_collectives LogGP-based collective operations
 * \{
 */
#ifdef __cplusplus
extern "C" {
#endif

/*!
 * The global instance of LogGP model for use in the optimized scatter/gather.
 * Must be initialized by \ref LogGP_initialize and destroyed by \ref LogGP_finalize
 * at all processes.
 */
extern PLogP_model* LogGP_model_instance;

/*! Sorted flat-tree scatterv based on the LogGP model. */
int LogGP_Scatterv_sorted_flat_asc(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree gatherv based on the LogGP model. */
int LogGP_Gatherv_sorted_flat_asc(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree scatterv based on the LogGP model. */
int LogGP_Scatterv_sorted_flat_dsc(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree gatherv based on the LogGP model. */
int LogGP_Gatherv_sorted_flat_dsc(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

#ifdef HAVE_LIBBOOST_GRAPH

/*! DFS binomial bcast based on the LogGP model. */
int LogGP_Bcast_dfs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! DFS binomial reduce based on the LogGP model. */
int LogGP_Reduce_dfs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! DFS binomial bcast based on the LogGP model. */
int LogGP_Bcast_dfs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! BFS binomial reduce based on the LogGP model. */
int LogGP_Reduce_bfs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! BFS binomial reduce based on the LogGP model. */
int LogGP_Reduce_bfs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! BFS binomial bcast based on the LogGP model. */
int LogGP_Bcast_bfs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! BFS binomial bcast based on the LogGP model. */
int LogGP_Bcast_bfs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! DFS binomial reduce based on the LogGP model. */
int LogGP_Reduce_dfs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! UCS binomial bcast based on the LogGP model. */
int LogGP_Bcast_ucs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! UCS binomial reduce based on the LogGP model. */
int LogGP_Reduce_ucs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! UCS binomial bcast based on the LogGP model. */
int LogGP_Bcast_ucs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! UCS binomial reduce based on the LogGP model. */
int LogGP_Reduce_ucs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! DFS binomial scatter based on the LogGP model. */
int LogGP_Scatter_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gather based on the LogGP model. */
int LogGP_Gather_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatter based on the LogGP model. */
int LogGP_Scatter_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gather based on the LogGP model. */
int LogGP_Gather_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatter based on the LogGP model. */
int LogGP_Scatter_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gather based on the LogGP model. */
int LogGP_Gather_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatter based on the LogGP model. */
int LogGP_Scatter_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gather based on the LogGP model. */
int LogGP_Gather_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatter based on the LogGP model. */
int LogGP_Scatter_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gather based on the LogGP model. */
int LogGP_Gather_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatter based on the LogGP model. */
int LogGP_Scatter_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gather based on the LogGP model. */
int LogGP_Gather_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_dfs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_dfs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_bfs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_bfs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_ucs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_ucs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Scatterv based on modified Traff using the LogGP model. */
int LogGP_Scatterv_Traff(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Gatherv based on modified Traff using the LogGP model. */
int LogGP_Gatherv_Traff(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

#endif// for HAVE_LIBBOOST_GRAPH

#ifdef __cplusplus
}
#endif
/*!
 * \}
 */

#endif /*LogGP_COLLECTIVES_H_*/

==> cpm-1.2.0.tar.gz: cpm-1.2.0/collectives/loggp_collectives.h <==
#ifndef LogGP_COLLECTIVES_H_
#define LogGP_COLLECTIVES_H_

#ifdef HAVE_CONFIG_H
#include "models/plogp.h"
#else
#include "plogp.h"
#endif

/*!
 * \defgroup loggp_collectives LogGP-based collective operations
 * \{
 */
#ifdef __cplusplus
extern "C" {
#endif

/*! Sorted flat-tree scatterv based on the LogGP model. */
int LogGP_Scatterv_sorted_flat_asc(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree gatherv based on the LogGP model. */
int LogGP_Gatherv_sorted_flat_asc(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree scatterv based on the LogGP model. */
int LogGP_Scatterv_sorted_flat_dsc(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree gatherv based on the LogGP model. */
int LogGP_Gatherv_sorted_flat_dsc(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial bcast based on the LogGP model. */
int LogGP_Bcast_dfs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! DFS binomial reduce based on the LogGP model. */
int LogGP_Reduce_dfs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! DFS binomial bcast based on the LogGP model. */
int LogGP_Bcast_dfs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! BFS binomial reduce based on the LogGP model. */
int LogGP_Reduce_bfs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! BFS binomial reduce based on the LogGP model. */
int LogGP_Reduce_bfs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! BFS binomial bcast based on the LogGP model. */
int LogGP_Bcast_bfs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! BFS binomial bcast based on the LogGP model. */
int LogGP_Bcast_bfs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! DFS binomial reduce based on the LogGP model. */
int LogGP_Reduce_dfs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! UCS binomial bcast based on the LogGP model. */
int LogGP_Bcast_ucs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! UCS binomial reduce based on the LogGP model. */
int LogGP_Reduce_ucs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! UCS binomial bcast based on the LogGP model. */
int LogGP_Bcast_ucs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! UCS binomial reduce based on the LogGP model. */
int LogGP_Reduce_ucs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! DFS binomial scatter based on the LogGP model. */
int LogGP_Scatter_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gather based on the LogGP model. */
int LogGP_Gather_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatter based on the LogGP model. */
int LogGP_Scatter_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gather based on the LogGP model. */
int LogGP_Gather_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatter based on the LogGP model. */
int LogGP_Scatter_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gather based on the LogGP model. */
int LogGP_Gather_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatter based on the LogGP model. */
int LogGP_Scatter_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gather based on the LogGP model. */
int LogGP_Gather_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatter based on the LogGP model. */
int LogGP_Scatter_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gather based on the LogGP model. */
int LogGP_Gather_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatter based on the LogGP model. */
int LogGP_Scatter_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gather based on the LogGP model. */
int LogGP_Gather_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_dfs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_dfs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_bfs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_bfs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_ucs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatterv based on the LogGP model. */
int LogGP_Scatterv_ucs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gatherv based on the LogGP model. */
int LogGP_Gatherv_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Scatterv based on modified Traff using the LogGP model. */
int LogGP_Scatterv_Traff(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Gatherv based on modified Traff using the LogGP model. */
int LogGP_Gatherv_Traff(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

#ifdef __cplusplus
}
#endif
/*!
 * \}
 */

#endif /*LogGP_COLLECTIVES_H_*/
